@@ -7,15 +7,18 @@ use binary_rw::{
 };
 
 fn create_writer_stream(name: &str) -> Filestream {
-    Filestream::new(name, OpenType::OpenAndCreate).expect("Failed to open stream")
+    let name = format!("{}.test", name);
+    Filestream::new(&name, OpenType::OpenAndCreate).expect("Failed to open stream")
 }
 
 fn create_reader_stream(name: &str) -> Filestream {
-    Filestream::new(name, OpenType::Open).expect("Failed to open stream")
+    let name = format!("{}.test", name);
+    Filestream::new(&name, OpenType::Open).expect("Failed to open stream")
 }
 
 fn cleanup(name: &str) {
-    std::fs::remove_file(name).expect("Failure to delete file");
+    let name = format!("{}.test", name);
+    std::fs::remove_file(&name).expect("Failure to delete file");
 }
 
 #[test]
@@ -299,29 +302,30 @@ fn read_out_of_range() {
         return;
     }
 
+    println!("read_out_of_range: {}", reader.get_cur_pos().unwrap());
+
     if reader.read_f32().is_err() {
+        cleanup("out_of_range");
         panic!("Out of range");
     }
-
-    cleanup("out_of_range");
 }
 
 #[test]
 fn read_write_string() {
     let temp = "Hello World";
-    let mut stream = create_writer_stream("out_of_range");
+    let mut stream = create_writer_stream("read_write_string");
     let mut writer = BinaryWriter::new(&mut stream);
 
     writer
         .write_string(temp.to_string())
         .expect("Failed to write string");
-    let mut stream = create_reader_stream("out_of_range");
+    let mut stream = create_reader_stream("read_write_string");
 
     let mut reader = BinaryReader::new(&mut stream);
     let string = reader.read_string().expect("Failed to read string");
     assert_eq!(temp, string);
 
-    cleanup("out_of_range");
+    cleanup("read_write_string");
 }
 
 #[test]
@@ -377,6 +381,9 @@ fn write_to_filestream_overlapping() {
     writer.write_f32(5.0).expect("Failed to overwrite f32");
     writer.write_f32(6.0).expect("Failed to overwrite f32");
 
+    let file = std::fs::File::open("filestream_overlapping.test").unwrap();
+    eprintln!("File size is {}", file.metadata().unwrap().len());
+
     let mut stream = create_reader_stream("filestream_overlapping");
     let mut reader = BinaryReader::new(&mut stream);
     let value = reader.read_f32().expect("Failed to read f32");
